Float32BufferAttribute class

Inheritance

Constructors

Float32BufferAttribute(Float32Array array, int itemSize, [bool normalized = false])

Properties

array ↔ Float32Array
getter/setter pairinherited
buffer ↔ int?
getter/setter pairinherited
count ↔ int
getter/setter pairinherited
data ↔ InterleavedBuffer?
getter/setter pairinherited
elementSize ↔ int?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isBufferAttribute ↔ bool
getter/setter pairinherited
itemSize ↔ int
getter/setter pairinherited
length → int
no setterinherited
name ↔ String?
getter/setter pairinherited
needsUpdate ← bool
no getterinherited
normalized ↔ bool
getter/setter pairinherited
onUploadCallback ↔ void Function()?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pairinherited
updateRange ↔ Map<String, int>?
getter/setter pairinherited
usage ↔ int
getter/setter pairinherited
version ↔ int
getter/setter pairinherited

Methods

applyMatrix3(Matrix3 m) → BufferAttribute<NativeArray<num>>
inherited
applyMatrix4(Matrix4 m) → void
inherited
applyNormalMatrix(dynamic m) → BufferAttribute<NativeArray<num>>
inherited
clone() → BufferAttribute<NativeArray<num>>
inherited
copy(BufferAttribute<NativeArray<num>> source) → BufferAttribute<NativeArray<num>>
inherited
copyArray(Float32Array array) → BufferAttribute<NativeArray<num>>
inherited
copyAt(int index1, BufferAttribute<NativeArray<num>> attribute, int index2) → BufferAttribute<NativeArray<num>>
inherited
copyColorsArray(List<Color> colors) → BufferAttribute<NativeArray<num>>
inherited
copyVector2sArray(List<Vector2> vectors) → BufferAttribute<NativeArray<num>>
inherited
copyVector3sArray(List<Vector3> vectors) → BufferAttribute<NativeArray<num>>
inherited
copyVector4sArray(List<Vector4> vectors) → BufferAttribute<NativeArray<num>>
inherited
getAt(int index) → num?
inherited
getW(int index) → num?
inherited
getX(int index) → num?
inherited
getY(int index) → num?
inherited
getZ(int index) → num?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUpload(void callback()?) → BufferAttribute<NativeArray<num>>
inherited
set(dynamic value, {int offset = 0}) → BufferAttribute<NativeArray<num>>
inherited
setUsage(int value) → BufferAttribute<NativeArray<num>>
inherited
setW(int index, dynamic w) → BufferAttribute<NativeArray<num>>
inherited
setX(int index, dynamic x) → BufferAttribute<NativeArray<num>>
inherited
setXY(int index, dynamic x, dynamic y) → BufferAttribute<NativeArray<num>>
inherited
setXYZ(int index, num x, num y, num z) → void
inherited
setXYZW(int index, dynamic x, dynamic y, dynamic z, dynamic w) → BufferAttribute<NativeArray<num>>
inherited
setY(int index, dynamic y) → BufferAttribute<NativeArray<num>>
inherited
setZ(int index, dynamic z) → BufferAttribute<NativeArray<num>>
inherited
toJSON([dynamic data]) → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited
transformDirection(Matrix4 m) → BufferAttribute<NativeArray<num>>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited