LightShadow class

Implementers

Constructors

LightShadow(Camera? camera)
LightShadow.fromJSON(Map<String, dynamic> json, Map<String, dynamic> rootJSON)

Properties

autoUpdate ↔ bool
getter/setter pair
bias ↔ num
getter/setter pair
blurSamples ↔ num
getter/setter pair
camera ↔ Camera?
getter/setter pair
focus ↔ num
getter/setter pair
frameExtents ↔ Vector2
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
map ↔ RenderTarget?
getter/setter pair
mapPass ↔ RenderTarget?
getter/setter pair
mapSize ↔ Vector2
getter/setter pair
matrix ↔ Matrix4
getter/setter pair
needsUpdate ↔ bool
getter/setter pair
normalBias ↔ num
getter/setter pair
radius ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewportCount ↔ num
getter/setter pair
viewports ↔ List<Vector4>
getter/setter pair

Methods

clone() → LightShadow
copy(LightShadow source) → LightShadow
dispose() → void
getFrameExtents() → Vector2
getFrustum() → Frustum
getViewport(int viewportIndex) → Vector4
getViewportCount() → num
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
updateMatrices(Light light, {int viewportIndex = 0}) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited