MaterialLoader class

Inheritance

Constructors

MaterialLoader(dynamic manager)

Properties

crossOrigin ↔ String
getter/setter pairinherited
flipY ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
manager ↔ LoadingManager
getter/setter pairinherited
mimeType ↔ String
getter/setter pairinherited
path ↔ String
getter/setter pairinherited
requestHeader ↔ Map<String, dynamic>
getter/setter pairinherited
resourcePath ↔ String?
getter/setter pairinherited
responseType ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textures ↔ Map
getter/setter pair
withCredentials ↔ bool
getter/setter pairinherited

Methods

load(dynamic url, Function onLoad, [Function? onProgress, Function? onError]) → dynamic
override
loadAsync(dynamic url) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic json, [String? path, Function? onLoad, Function? onError]) → dynamic
override
setCrossOrigin(dynamic crossOrigin) → dynamic
inherited
setPath(dynamic path) → dynamic
inherited
setRequestHeader(dynamic requestHeader) → dynamic
inherited
setResourcePath(dynamic resourcePath) → dynamic
inherited
setTextures(dynamic value) → dynamic
setWithCredentials(dynamic value) → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited