Plane class

Constructors

Plane([Vector3? normal, double? constant])

Properties

constant ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
normal ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair

Methods

applyMatrix4(Matrix4 matrix, [Matrix3? optionalNormalMatrix]) → Plane
clone() → Plane
coplanarPoint(Vector3 target) → Vector3
copy(Plane plane) → Plane
distanceToPoint(Vector3 point) → num
distanceToSphere(Sphere sphere) → num
equals(Plane plane) → bool
intersectLine(Line3 line, Vector3 target) → Vector3?
intersectsBox(Box3 box) → bool
intersectsLine(Line3 line) → bool
intersectsSphere(Sphere sphere) → bool
negate() → Plane
normalize() → Plane
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
projectPoint(Vector3 point, Vector3 target) → Vector3
set(Vector3 normal, double constant) → Plane
setComponents(double x, double y, double z, double w) → Plane
setFromCoplanarPoints(Vector3 a, Vector3 b, Vector3 c) → Plane
setFromNormalAndCoplanarPoint(Vector3 normal, Vector3 point) → Plane
toJSON() → List<num>
toString() → String
A string representation of this object.
inherited
translate(Vector3 offset) → Plane

Operators

operator ==(Object other) → bool
The equality operator.
inherited