Spherical class

Constructors

Spherical({num radius = 1, num phi = 0, num theta = 0})

Properties

hashCode → int
The hash code for this object.
no setterinherited
phi ↔ num
getter/setter pair
radius ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theta ↔ num
getter/setter pair

Methods

clone() → Spherical
copy(Spherical other) → Spherical
makeSafe() → Spherical
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(num radius, num phi, num theta) → Spherical
setFromCartesianCoords(num x, num y, num z) → Spherical
setFromVector3(dynamic v) → Spherical
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited