UuidValue class

Constructors

UuidValue(String uuid, [bool validate = true, ValidationMode validationMode = ValidationMode.strictRFC4122])
UuidValue() Constructor for creating a uuid value.
factory
UuidValue.fromByteList(Uint8List byteList, {int? offset})
factory
UuidValue.fromList(List<int> byteList, {int? offset})
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid → String
final

Methods

equals(UuidValue other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override