Skeleton class

Constructors

Skeleton([List<Bone> bones = const [], List<Matrix4>? boneInverses])

Properties

boneInverses ↔ List<Matrix4>
getter/setter pair
boneMatrices ↔ Float32Array
getter/setter pair
bones ↔ List<Bone>
getter/setter pair
boneTexture ↔ DataTexture?
getter/setter pair
boneTextureSize ↔ int
getter/setter pair
frame ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid ↔ String
getter/setter pair

Methods

calculateInverses() → void
clone() → Skeleton
computeBoneTexture() → Skeleton
dispose() → void
fromJSON(dynamic json, dynamic bones) → dynamic
getBoneByName(dynamic name) → Bone?
getValue(String name) → dynamic
init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pose() → void
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
update() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited