WebGLRenderTargetOptions class

Constructors

WebGLRenderTargetOptions(Map<String, dynamic> json)

Properties

anisotropy ↔ int?
getter/setter pair
depthBuffer ↔ bool?
getter/setter pair
depthTexture ↔ DepthTexture?
getter/setter pair
encoding ↔ int?
getter/setter pair
format ↔ int?
getter/setter pair
generateMipmaps ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoreDepth ↔ bool
getter/setter pair
magFilter ↔ int?
getter/setter pair
mapping ↔ int?
getter/setter pair
minFilter ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples ↔ int?
getter/setter pair
stencilBuffer ↔ bool
getter/setter pair
type ↔ int?
getter/setter pair
useMultisampleRenderToTexture ↔ bool
getter/setter pair
useRenderToTexture ↔ bool
getter/setter pair
wrapS ↔ int?
getter/setter pair
wrapT ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited